@@ -1,32 +1,21 @@
 # -*- coding: utf-8 -*-
+"""Functional GUI tests.
 
-'''
-Test GUI with a few functional tests (as opposed to unit tests that cover every
-function, or integration tests):
-
-https://codeutopia.net/blog/2015/04/11/what-are-unit-testing-integration-
-testing-and-functional-testing/
-
-"You shouldn’t try to make very fine grained functional tests. You don’t want
-to test a single function, despite the name “functional” perhaps hinting at it.
-Instead, functional tests should be used for testing common user interactions.
-If you would manually test a certain flow of your app in a browser, such as
-registering an account, you could make that into a functional test."
-
-The tests will be restricted to a few typical, meaningful workflows (i.e.,
+Test GUI with a few functional tests (as opposed to unit tests or integration
+tests). The tests are restricted to a few meaningful workflows (i.e.,
 sequences of function calls), since testing all possible workflows is
 unfeasible and for a majority of workflows meaningless (e.g., saving peaks
 before finding peaks etc.).
 
-Note that the timeouts used in qtbot.waitSignal(s) might cause flaky tests
+IMPORTANT: The timeouts used in qtbot.waitSignal(s) might cause flaky tests
 depending on which machine runs the tests.
-'''
+"""
 
 import pytest
 from pathlib import Path
 import numpy as np
 import pandas as pd
-from PySide2.QtCore import Qt
+from PySide6.QtCore import Qt
 from biopeaks.model import Model
 from biopeaks.view import View
 from biopeaks.controller import Controller
@@ -174,7 +163,7 @@ rsp_os = {"modality": "RESP",
           "filetype": "OpenSignals"}
 
 rsp_custom = {"modality": "RESP",
-              "header" : {"signalidx": 6, "markeridx": 1, "skiprows": 3,
+              "header": {"signalidx": 6, "markeridx": 1, "skiprows": 3,
                           "sfreq": 1000, "separator": "\t"},
               "mode": "single file",
               "sigpathorig": datadir.joinpath("OSmontage0J.txt"),
@@ -226,6 +215,7 @@ def idcfg_single(cfg):
                         rsp_os, rsp_custom, rsp_edf],
                 ids=idcfg_single)    # automatically runs the test(s) using this fixture with all values of params
 def cfg_single(request):
+
     return request.param
 
 
@@ -252,7 +242,7 @@ def test_singlefile(qtbot, tmpdir, cfg_single):
     model.fpaths = [cfg_single["sigpathorig"]]
     with qtbot.waitSignals([model.signal_changed, model.marker_changed],
                            timeout=10000):
-        controller.read_channels()
+        controller._load_channels()
     assert np.size(model.signal) == cfg_single["siglen"]
     assert np.size(model.sec) == cfg_single["siglen"]
     assert np.size(model.marker) == cfg_single["markerlen"]
@@ -265,7 +255,7 @@ def test_singlefile(qtbot, tmpdir, cfg_single):
         model.set_segment(values=cfg_single["segment"])
     assert model.segment == cfg_single["segment"]
     with qtbot.waitSignal(model.signal_changed, timeout=5000):
-        controller.segment_signal()
+        controller.segment_dataset()
     seg = int(np.rint((cfg_single["segment"][1] - cfg_single["segment"][0]) *
                       model.sfreq))
     assert np.allclose(np.size(model.signal), seg, atol=1)
@@ -274,7 +264,7 @@ def test_singlefile(qtbot, tmpdir, cfg_single):
     # 3. save segment ########################################################
     model.wpathsignal = tmpdir.join(cfg_single["sigfnameseg"])
     with qtbot.waitSignals([model.progress_changed] * 2, timeout=10000):
-        controller.save_channels()
+        controller._save_channels()
 
     # 4. find extrema #########################################################
     with qtbot.waitSignal(model.peaks_changed, timeout=5000):
@@ -304,19 +294,19 @@ def test_singlefile(qtbot, tmpdir, cfg_single):
     # 6. save peaks ###########################################################
     model.wpathpeaks = tmpdir.join(cfg_single["peakfname"])
     with qtbot.waitSignals([model.progress_changed] * 2, timeout=10000):
-        controller.save_peaks()
+        controller._save_peaks()
 
     # 7. re-load signal #######################################################
     model.fpaths = [tmpdir.join(cfg_single["sigfnameseg"])]
     with qtbot.waitSignals([model.signal_changed, model.marker_changed],
                            timeout=10000):
-        controller.read_channels()
+        controller._load_channels()
     sfreq = cfg_single["header"]["sfreq"] if cfg_single["filetype"] == "Custom" else cfg_single["sfreq"]
     assert model.sfreq == sfreq
     assert model.loaded
     # Increase tolerance to 38, since for EDF files data needs to be saved as
     # epochs of fixed size which can lead to deviations from original segment
-    # length.
+    # length (signal might be shortened by a few samples during saving).
     assert np.allclose(np.size(model.signal), seg, atol=38)
     assert np.allclose(np.size(model.sec), seg, atol=38)
     assert np.size(model.signal) == np.size(model.sec)
@@ -324,7 +314,7 @@ def test_singlefile(qtbot, tmpdir, cfg_single):
     # 8. load peaks ###########################################################
     model.rpathpeaks = tmpdir.join(cfg_single["peakfname"])
     with qtbot.waitSignal(model.peaks_changed, timeout=5000):
-        controller.read_peaks()
+        controller._load_peaks()
     # For the breathing, after peak editing, the re-inserted peak can
     # be shifted by a few samples. This is not a bug, but inherent in the
     # way extrema are added and deleted in controller.edit_peaks().
@@ -349,8 +339,7 @@ def test_singlefile(qtbot, tmpdir, cfg_single):
         view.tidalampcheckbox.setCheckState(Qt.Checked)
     model.wpathstats = tmpdir.join(cfg_single["statsfname"])
     with qtbot.waitSignals([model.progress_changed] * 2, timeout=10000):
-        controller.save_stats()
-    # load and check content
+        controller._save_stats()
     stats = pd.read_csv(tmpdir.join(cfg_single["statsfname"]))
     assert np.around(stats["period"].mean(), 4) == cfg_single["avgperiod"]
     assert np.around(stats["rate"].mean(), 4) == cfg_single["avgrate"]
@@ -366,11 +355,11 @@ ecg_batch_os = {"modality": "ECG",
                 "sigfnames": ["OSmontage1A.txt", "OSmontage1J.txt",
                               "OSmontage2A.txt", "OSmontage2J.txt",
                               "OSmontage3A.txt", "OSmontage3J.txt"],
-                "peaksums": [3808244, 3412308, 2645824, 3523449, 3611836,
-                             3457936],
-                "stats": [(0.7950, 76.1123), (0.7288, 83.1468),
-                          (0.7894, 76.8911), (0.7402, 81.7864),
-                          (0.7856, 76.9153), (0.7235, 83.6060)],
+                "peaksums": [3828709, 3434713, 2666196, 3546319, 3611836,
+                             3480340],
+                "stats": [(0.7916, 76.3624), (0.7285, 83.1771),
+                          (0.7889, 76.9233), (0.7402, 81.7879),
+                          (0.7856, 76.9153), (0.7234, 83.6239)],
                 "correctpeaks": False}
 
 ecg_batch_custom = {"modality": "ECG",
@@ -381,11 +370,11 @@ ecg_batch_custom = {"modality": "ECG",
                     "sigfnames": ["OSmontage1A.txt", "OSmontage1J.txt",
                                   "OSmontage2A.txt", "OSmontage2J.txt",
                                   "OSmontage3A.txt", "OSmontage3J.txt"],
-                    "peaksums": [3808244, 3412308, 2645824, 3523449, 3611836,
-                                 3457936],
-                    "stats": [(0.7950, 76.1123), (0.7288, 83.1468),
-                              (0.7894, 76.8911), (0.7402, 81.7864),
-                              (0.7856, 76.9153), (0.7235, 83.6060)],
+                    "peaksums": [3828709, 3434713, 2666196, 3546319, 3611836,
+                                 3480340],
+                    "stats": [(0.7916, 76.3624), (0.7285, 83.1771),
+                              (0.7889, 76.9233), (0.7402, 81.7879),
+                              (0.7856, 76.9153), (0.7234, 83.6239)],
                     "correctpeaks": False}
 
 ecg_batch_autocorrect = {"modality": "ECG",
@@ -395,16 +384,16 @@ ecg_batch_autocorrect = {"modality": "ECG",
                          "sigfnames": ["OSmontage1A.txt", "OSmontage1J.txt",
                                        "OSmontage2A.txt", "OSmontage2J.txt",
                                        "OSmontage3A.txt", "OSmontage3J.txt"],
-                         "peaksums": [3808199, 3394481, 2626449, 3511241,
-                                      3611833, 3457931],
-                         "stats": [(0.7944, 76.0973), (0.7308, 82.8572),
-                                   (0.7934, 76.2351), (0.7418, 81.5011),
-                                   (0.7856, 76.9152), (0.7235, 83.5973)],
+                         "peaksums": [3828678, 3416886, 2644580, 3534109,
+                                      3611833, 3480341],
+                         "stats": [(0.7914, 76.3427), (0.7305, 82.8876),
+                                   (0.7942, 75.954), (0.7418, 81.5025),
+                                   (0.7856, 76.9152), (0.7233, 83.6178)],
                          "correctpeaks": True}
 
 
 def idcfg_batch(cfg):
-    """Generate a test ID."""
+
     modality = cfg["modality"]
     filetype = cfg["filetype"]
     if cfg["correctpeaks"]:
@@ -417,6 +406,7 @@ def idcfg_batch(cfg):
 @pytest.fixture(params=[ecg_batch_os, ecg_batch_custom, ecg_batch_autocorrect],
                 ids=idcfg_batch)
 def cfg_batch(request):
+
     return request.param
 
 
@@ -445,27 +435,27 @@ def test_batchfile(qtbot, tmpdir, cfg_batch):
     model.set_filetype(cfg_batch["filetype"])
 
     # Mock the controller's batch_processor in order to avoid
-    # calls to the controller's get_wpathpeaks and get_wpathstats methods.
+    # calls to the controller's save_peaks and save_stats methods.
     model.wdirpeaks = tmpdir
     model.wdirstats = tmpdir
 
     model.status = 'processing files'
     model.plotting = False
 
-    controller.batchmethods = [controller.read_channels, controller.find_peaks,
+    controller.batchmethods = [controller._load_channels, controller.find_peaks,
                                controller.autocorrect_peaks,
                                controller.calculate_stats,
-                               controller.save_stats,
-                               controller.save_peaks]
+                               controller._save_stats,
+                               controller._save_peaks]
     controller.iterbatchmethods = iter(controller.batchmethods)
 
-    model.progress_changed.connect(controller.dispatcher)
+    model.progress_changed.connect(controller._dispatcher)
 
     # Initiate batch processing.
-    controller.dispatcher(1)
+    controller._dispatcher(1)
 
     # Wait for all files to be processed.
-    while not model.plotting:    # dispatcher enables plotting once all files are processed
+    while not model.plotting:    # _dispatcher enables plotting once all files are processed
         qtbot.wait(1000)
 
     # Load each peak file saved during batch processing and assess if
@@ -474,16 +464,16 @@ def test_batchfile(qtbot, tmpdir, cfg_batch):
                                  cfg_batch["peaksums"]):
         with qtbot.waitSignal(model.signal_changed, timeout=5000):
             model.fpaths = [datadir.joinpath(sigfname)]
-            controller.read_channels()
+            controller._load_channels()
         fname = Path(sigfname).stem
         model.rpathpeaks = tmpdir.join(f"{fname}_peaks.csv")
         with qtbot.waitSignal(model.peaks_changed, timeout=5000):
-            controller.read_peaks()
+            controller._load_peaks()
         assert sum(model.peaks) == peaksum
         model.reset()
 
     # Load each stats file saved during batch processing and assess if
-    # stats have been caclualted correctly.
+    # stats have been calculated correctly.
     for sigfname, stat in zip(cfg_batch["sigfnames"], cfg_batch["stats"]):
         fname = Path(sigfname).stem
         statsfname = tmpdir.join(f"{fname}_stats.csv")
